@@ -1,12 +1,12 @@
-from PyQt5.QtCore import Qt, QCoreApplication, pyqtSignal, QVariant
-from PyQt5.QtGui import  QPixmap, QPainter, QColor
-from PyQt5.QtWidgets import (QVBoxLayout, QHBoxLayout, QLabel, QTextEdit, QWidget,
+from PyQt5.QtCore import Qt, QVariant
+from PyQt5.QtGui import  QPixmap
+from PyQt5.QtWidgets import (QVBoxLayout, QHBoxLayout, QLabel, QWidget,
         QComboBox, QCheckBox, QGridLayout, QSpacerItem, QLineEdit, QPushButton)
 from PyQt5.QtCore import QCoreApplication as QC
 import logging, os, Pythonic
 from Pythonic.elementeditor import ElementEditor
-from Pythonic.record_function import Record, Function
-from Pythonic.elementmaster import ElementMaster, alphabet
+from Pythonic.record_function import Record, Function, alphabet
+from Pythonic.elementmaster import ElementMaster
 
 
 class ExecBranch(ElementMaster):
