@@ -471,30 +471,10 @@ class WorkingArea(QFrame):
                     self.grid.addWidget(link, row, col-1)
                     element.widget().parent_element = link
 
-    def saveGrid(self, filename):
 
-        logging.debug('WorkingArea::saveGrid() called with fileName {}'.format(filename))
-        grid_cols = range(0, self.grid.columnCount())
-        grid_rows = range(0, self.grid.rowCount())
+    def saveGrid(self):
 
-        element_list = []
-
-        index = ((row, column) for row in grid_rows for column in grid_cols)
-
-        for pos in index:
-            row, col = pos
-            logging.debug('WorkingArea::saveGrid() check position: {} {}'.format(row, col))
-            element = self.grid.itemAtPosition(row, col)
-            if element:
-                logging.debug('WorkingArea::saveGrid() element found at: {} {}'.format(row, col))
-                element_list.append(element.widget())
-
-        with open(filename + self.file_extension, 'wb') as save_file:
-            pickle.dump(element_list, save_file)
-
-    def saveGridWorker(self, filename):
-
-        logging.debug('WorkingArea::saveGridWorker() called with fileName {}'.format(filename))
+        logging.debug('WorkingArea::saveGridWorker() called')
 
         grid_cols = range(0, self.grid.columnCount())
         grid_rows = range(0, self.grid.rowCount())
@@ -511,10 +491,11 @@ class WorkingArea(QFrame):
                 # Element description: (pos, function, config, self_sync)
                 logging.debug('WorkingArea::saveGrid() element found at: {} {}'.format(row, col))
                 element = element.widget()
-                element_list.append((pos, element.function, element.config, element.self_sync))
+                element_type = type(element).__name__
 
-        with open((filename + '.d' + self.file_extension), 'wb') as save_file:
-            pickle.dump(element_list, save_file)
+                element_list.append((pos, element_type, element.function, element.config, element.self_sync))
+
+        return pickle.dumps(element_list)
 
     def clearGrid(self): 
 
@@ -539,45 +520,38 @@ class WorkingArea(QFrame):
 
         self.addPlaceholder(1, 0)
 
+    def loadGrid(self, element_list):
 
-    def loadGrid(self, filename):
-
-        logging.debug('WorkingArea::loadGrid() called with filename {}'.format(filename))
-        
-        try:
-            f = open(filename, 'rb')
-            try:
-                element_list = pickle.load(f)
-                self.clearGrid()
-            finally:
-                f.close()
-        except Exception as e:
-            logging.error('loadGrid() file cant be read: {}'.format(e))
-
-            self.msg = QMessageBox()
-            self.msg.setWindowTitle('Invalid format')
-            self.msg.setText('File can\'t be read')
-            self.msg.setIcon(QMessageBox.Critical)
-            self.msg.setStyleSheet('background-color: lightgrey')
-            self.msg.exec()
-            return
+        logging.debug('WorkingArea::loadGrid() called')
 
+        self.clearGrid()
         # populate the grid
+
         for element in element_list:
-            
-            row, col = element.getPos()
-            logging.debug('WorkingArea::loadGrid() ADD current element: row: {} col: {}'.format(
-                row, col))
-            logging.debug('WorkingArea::loadGrid() ADD element:{}'.format(
-                element))
-            logging.debug('WorkingArea::loadGrid() ADD element type:{}'.format(
-                type(element)))
-
-            self.grid.addWidget(element, row, col)
+            pos, element_type, function, config, self_sync = element
+            row, column = pos
+            #logging.debug('MainWorker::loadGrid() row: {} col: {}'.format(row, column))
+            #logging.debug('MainWorker::loadGrid() type: {}'.format(element_type))
+            logging.debug('MainWorker::loadGrid() type: {}'.format(element_type))
+            new_type_str = 'new_type = ' + element_type + '({},{})'.format(row, column)
+            logging.debug('WorkingArea::addElement() called, new_type_str: {}'.format(new_type_str))
+            try:
+                exec(new_type_str, globals())
+            except Exception as e:
+                logging.error('WorkingArea::addElement()- desired element type not found')
+                logging.error(e)
+                return
+            # Skip elements without config
+            new_type.__setstate__((row, column, config))
+            self.grid.addWidget(new_type, row, column, Qt.AlignCenter)
 
+        
+        #new_type_str = 'new_type = ' + newType + '({},{})'.format(row, column)
         # second run: add child and parent relation
         for element in element_list:
-            row, col = element.getPos()
+            pos, element_type, function, config, self_sync = element
+            row, col = pos
+            element = self.grid.itemAtPosition(*pos).widget()
                 
             if element.child_pos[0]:
 
